aboutsummaryrefslogtreecommitdiffstats
path: root/include/ruby/impl/intern/load.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/load.h')
-rw-r--r--include/ruby/impl/intern/load.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/ruby/impl/intern/load.h b/include/ruby/impl/intern/load.h
index b0b230262f..83a2bee5bf 100644
--- a/include/ruby/impl/intern/load.h
+++ b/include/ruby/impl/intern/load.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_LOAD_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_LOAD_H
+#ifndef RBIMPL_INTERN_LOAD_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_LOAD_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -23,7 +23,7 @@
#include "ruby/impl/dllexport.h"
#include "ruby/impl/value.h"
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
/* load.c */
void rb_load(VALUE, int);
@@ -34,6 +34,6 @@ void rb_provide(const char*);
VALUE rb_f_require(VALUE, VALUE);
VALUE rb_require_string(VALUE);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_INTERN_LOAD_H */
+#endif /* RBIMPL_INTERN_LOAD_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file